==> db4o-5.0-mono.tar.gz: db4o-5.0/src/core/src/core/com/db4o/inside/freespace/FreespaceIxLength.cs <==
/* Copyright (C) 2004 - 2005  db4objects Inc.  http://www.db4o.com

This file is part of the db4o open source object database.

db4o is free software; you can redistribute it and/or modify it under
the terms of version 2 of the GNU General Public License as published
by the Free Software Foundation and as clarified by db4objects' GPL 
interpretation policy, available at
http://www.db4o.com/about/company/legalpolicies/gplinterpretation/
Alternatively you can write to db4objects, Inc., 1900 S Norfolk Street,
Suite 350, San Mateo, CA 94403, USA.

db4o is distributed in the hope that it will be useful, but WITHOUT ANY
WARRANTY; without even the implied warranty of MERCHANTABILITY or
FITNESS FOR A PARTICULAR PURPOSE.  See the GNU General Public License
for more details.

You should have received a copy of the GNU General Public License along
with this program; if not, write to the Free Software Foundation, Inc.,
59 Temple Place - Suite 330, Boston, MA  02111-1307, USA. */
namespace com.db4o.inside.freespace
{
	internal class FreespaceIxLength : com.db4o.inside.freespace.FreespaceIx
	{
		internal FreespaceIxLength(com.db4o.YapFile file, com.db4o.MetaIndex metaIndex) : 
			base(file, metaIndex)
		{
		}

		internal override void add(int address, int length)
		{
			_index._handler.prepareComparison(length);
			_indexTrans.add(address, length);
		}

		internal override int address()
		{
			return _visitor._key;
		}

		internal override int length()
		{
			return _visitor._value;
		}

		internal override void remove(int address, int length)
		{
			_index._handler.prepareComparison(length);
			_indexTrans.remove(address, length);
		}
	}
}

==> db4o-5.5-mono.tar.gz: db4o-5.5/src/core/src/core/com/db4o/inside/freespace/FreespaceIxLength.cs <==
/* Copyright (C) 2004 - 2006  db4objects Inc.  http://www.db4o.com

This file is part of the db4o open source object database.

db4o is free software; you can redistribute it and/or modify it under
the terms of version 2 of the GNU General Public License as published
by the Free Software Foundation and as clarified by db4objects' GPL 
interpretation policy, available at
http://www.db4o.com/about/company/legalpolicies/gplinterpretation/
Alternatively you can write to db4objects, Inc., 1900 S Norfolk Street,
Suite 350, San Mateo, CA 94403, USA.

db4o is distributed in the hope that it will be useful, but WITHOUT ANY
WARRANTY; without even the implied warranty of MERCHANTABILITY or
FITNESS FOR A PARTICULAR PURPOSE.  See the GNU General Public License
for more details.

You should have received a copy of the GNU General Public License along
with this program; if not, write to the Free Software Foundation, Inc.,
59 Temple Place - Suite 330, Boston, MA  02111-1307, USA. */
namespace com.db4o.inside.freespace
{
	internal class FreespaceIxLength : com.db4o.inside.freespace.FreespaceIx
	{
		internal FreespaceIxLength(com.db4o.YapFile file, com.db4o.MetaIndex metaIndex) : 
			base(file, metaIndex)
		{
		}

		internal override void Add(int address, int length)
		{
			_index._handler.PrepareComparison(length);
			_indexTrans.Add(address, length);
		}

		internal override int Address()
		{
			return _visitor._key;
		}

		internal override int Length()
		{
			return _visitor._value;
		}

		internal override void Remove(int address, int length)
		{
			_index._handler.PrepareComparison(length);
			_indexTrans.Remove(address, length);
		}
	}
}
